ziggy.hdmc.hdfs.hdfs_access

Package ziggy :: Package hdmc :: Package hdfs :: Module hdfs_access |
[hide private]
[frames] | no frames]

# Module hdfs_access

source code

Created on May 17, 2010

Author: dwmclary

Functions | [hide private]
run(args) Generic runner for HDFS access | source code
cat(filename) Runs HDFS cat on a filename or glob passed as a string Returns the result as a string read from STOUT | source code
ls(filename) Runs HDFS ls on a directory or glob passed as a string Returns the result as a string read from STOUT | source code
tail(filename) | source code
rm(filename) Runs HDFS rmr on a filename or glob passed as a string Returns the result as a string read from STOUT | source code
delete(filename) Runs HDFS rmr on a filename or glob passed as a string Returns the result as a string read from STOUT | source code
mkdir(dirname) Runs HDFS mkdir on a directory name as a string Returns the result as a string read from STOUT | source code
get_merge(pattern, dst) Runs HDFS rmr on a filename or glob passed as a string Returns the result as a string read from STOUT | source code
mv(src, dst) Runs HDFS mv: move src HDFS file to dst Returns the result as a string read from STOUT | source code
copyToHDFS(filename, hdfs_filename) | source code
copyFromHDFS(hdfs_filename, filename) | source code

Variables | [hide private]
| __package__ = ``'``ziggy.hdmc.hdfs``'``